@@ -7,6 +7,8 @@ from inspect import currentframe as cf
 from .exceptions import *
 from .helpers import CurrenciesIDs, MarketsIDs
 
+from logging import Logger
+
 
 __all__ = [
     'Bitpin',
@@ -15,7 +17,8 @@ __all__ = [
 
 class Bitpin:
     def __init__(self, api_key: t.Optional[str] = None, api_secret: t.Optional[str] = None,
-                 requests_params: t.Optional[t.Dict] = None):
+                 requests_params: t.Optional[t.Dict] = None,
+                 logger: t.Optional[t.Union[Logger, t.Type[Logger]]] = Logger()):
         """
         Initialize the Bitpin SDK .
 
@@ -42,6 +45,8 @@ class Bitpin:
 
         self.__base_url = 'https://api.bitpin.ir'
 
+        self._logger = logger
+
         # set timeout from requests_params
         if requests_params is not None:
             self.__timeout = requests_params.get('timeout') or 10
@@ -207,9 +212,14 @@ class Bitpin:
         :rtype: dict
         """
 
-        self._raise_for_exception(func_name, response, additional)
+        try:
+            self._raise_for_exception(func_name, response, additional)
+        except Exception as e:
+            self._logger.error(f'{response.request.url} failed {e}')
+            raise e
         if response.request.method.lower() == 'delete':
             return {'success': True}
+        self._logger.info(f'{response.request.url} success {response.json()}')
         return response.json()
 
     def __request(
